@@ -68,13 +68,7 @@ on_sigusr1_cb (gpointer user_data)
 static gboolean
 is_debug_set (void)
 {
-        gboolean debug = FALSE;
-
-        /* enable debugging for unstable builds */
-        if (gdm_is_version_unstable ()) {
-                return TRUE;
-        }
-
+        gboolean debug;
         gdm_settings_direct_get_boolean (GDM_KEY_DEBUG, &debug);
         return debug;
 }
